﻿Imports System
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Media

Public Class SkewTransition
    Inherits PageTransition
    Private pageContainers(2) As FrameworkElement
    Private compositeTransforms(2) As CompositeTransform

    Public Overrides ReadOnly Property AnimationDuration() As Double
        Get
            Return 500
        End Get
    End Property

    Public Overrides Sub Attach(ByVal containerPanel As Panel, ByVal pageContainer0 As FrameworkElement, ByVal pageContainer1 As FrameworkElement, ByVal pageContainer2 As FrameworkElement)
        pageContainers(0) = pageContainer0
        pageContainers(1) = pageContainer1
        pageContainers(2) = pageContainer2

        For i = 0 To 2
            compositeTransforms(i) = New CompositeTransform()
            pageContainers(i).RenderTransform = compositeTransforms(i)
        Next i
    End Sub

    Public Overrides Sub Detach()
        For Each pageContainer In pageContainers
            pageContainer.RenderTransform = Nothing
        Next pageContainer
    End Sub

    Protected Overrides Sub ShowPageTransition(ByVal baseIndex As Integer, ByVal fraction As Double)
        Dim nextIndex As Integer = (baseIndex + 1) Mod 3
        Dim prevIndex As Integer = (baseIndex + 2) Mod 3

        If fraction > -0.5 AndAlso fraction < 0.5 Then
            compositeTransforms(baseIndex).CenterY = pageContainers(baseIndex).ActualHeight
            compositeTransforms(nextIndex).CenterY = pageContainers(nextIndex).ActualHeight
            compositeTransforms(prevIndex).CenterY = pageContainers(prevIndex).ActualHeight

            compositeTransforms(prevIndex).SkewX = fraction * 360 * Math.Atan2(pageContainers(baseIndex).ActualWidth, pageContainers(baseIndex).ActualHeight) / Math.PI
            compositeTransforms(nextIndex).SkewX = compositeTransforms(prevIndex).SkewX
            compositeTransforms(baseIndex).SkewX = compositeTransforms(nextIndex).SkewX

            compositeTransforms(baseIndex).TranslateX = 0
            compositeTransforms(nextIndex).TranslateX = compositeTransforms(baseIndex).TranslateX + pageContainers(baseIndex).ActualWidth
            compositeTransforms(prevIndex).TranslateX = compositeTransforms(baseIndex).TranslateX - pageContainers(prevIndex).ActualWidth
        Else
            compositeTransforms(baseIndex).CenterY = 0
            compositeTransforms(nextIndex).CenterY = 0
            compositeTransforms(prevIndex).CenterY = 0

            compositeTransforms(prevIndex).SkewX = (Math.Sign(fraction) - fraction) * 360 * Math.Atan2(pageContainers(baseIndex).ActualWidth, pageContainers(baseIndex).ActualHeight) / Math.PI
            compositeTransforms(nextIndex).SkewX = compositeTransforms(prevIndex).SkewX
            compositeTransforms(baseIndex).SkewX = compositeTransforms(nextIndex).SkewX

            compositeTransforms(baseIndex).TranslateX = -pageContainers(prevIndex).ActualWidth
            compositeTransforms(nextIndex).TranslateX = compositeTransforms(baseIndex).TranslateX + pageContainers(baseIndex).ActualWidth
            compositeTransforms(prevIndex).TranslateX = compositeTransforms(baseIndex).TranslateX - pageContainers(prevIndex).ActualWidth
        End If
    End Sub
End Class